MockRequest class

Description of an incoming request as seen by MockHttpClient.

Constructors

MockRequest({required String method, required Uri url, required Map<String, String> headers, String? body})
Build a mock request.

Properties

body → String?
Request body, if any.
final
hashCode → int
The hash code for this object.
no setterinherited
headers → Map<String, String>
Request headers, lower-cased keys.
final
method → String
HTTP method (GET, POST, ...).
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
url → Uri
Target URL.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited