MockResponse class

Description of a stubbed response.

Constructors

MockResponse({int status = 200, Object? body, Map<String, String> headers = const {'content-type' : 'application/json'}})
Build a stubbed response.
const

Properties

body Object?
Response body — either a String, a Map, or null.
final
hashCode int
The hash code for this object.
no setterinherited
headers Map<String, String>
Response headers.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status int
HTTP status to return.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited