ApiTokensResource class

CRUD for /v1/api-tokens.

Constructors

ApiTokensResource(CoffrifyHttpClient _http)
Build the resource.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

create({required String name, int? expiresInMinutes, int? maxUses, List<String>? scopes}) Future<Map<String, dynamic>>
Mint a delegated token. token is shown ONCE.
list() Future<List<Map<String, dynamic>>>
List delegated tokens.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
revoke(String id) Future<void>
Revoke a delegated token.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited