OnErrorContext class

Payload supplied to ClientHooks.onError.

Annotations
  • @immutable

Constructors

OnErrorContext({required String method, required Uri url, required Object error, required int attempt})
Build an error context.
const

Properties

attempt int
0-indexed attempt number at which the error was raised.
final
error Object
Underlying error object.
final
hashCode int
The hash code for this object.
no setterinherited
method String
HTTP method.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
url Uri
Request URL.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited