RetryPolicy class abstract

A pluggable strategy that decides whether and when to retry a failed request. Implementations must be cheap and synchronous.

Implementers

Constructors

RetryPolicy()
Const constructor for subclasses.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

next(int attempt, RetryContext ctx) RetryDecision
Decide what to do after the attemptth failure (0-indexed).
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited