TemplatesResource class

CRUD for /v1/templates (reusable transfer policies).

Constructors

TemplatesResource(CoffrifyHttpClient _http)
Build the resource.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

create(Map<String, dynamic> opts) Future<Map<String, dynamic>>
Create a template. opts must include name.
delete(String id) Future<void>
Delete a template.
list() Future<List<Map<String, dynamic>>>
List templates.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited