MockResponse class
Description of a stubbed response.
Constructors
Properties
- body → Object?
-
Response body — either a
String, aMap, ornull.final - hashCode → int
-
The hash code for this object.
no setterinherited
-
headers
→ Map<
String, String> -
Response headers.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → int
-
HTTP status to return.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited