ApiKeyList class
List response for ApiKeysResource.list.
Constructors
-
ApiKeyList({required List<
CoffrifyApiKey> keys, required String plan}) -
Build a list response.
const
-
ApiKeyList.fromJson(Map<
String, dynamic> json) -
Build from a JSON map.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
keys
→ List<
CoffrifyApiKey> -
Keys returned.
final
- plan → String
-
Workspace plan (drives quotas).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited