Page<T> class
One page of items returned by a list endpoint.
- Annotations
-
- @immutable
Constructors
Properties
-
data
→ List<
T> -
Items returned by this page.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasMore → bool?
-
truewhen there is at least one more page.final - nextCursor → String?
-
Opaque cursor pointing at the next page, when the endpoint supports
cursor pagination.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- total → int?
-
Total item count when known by the server.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited