Static factories for building plausible Coffrify objects in tests.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
apiKey(
{String? id, String? name, String environment = 'live', bool isActive = true}) → CoffrifyApiKey - Build a CoffrifyApiKey with overridable fields.
-
auditEntry(
{String? id, String? workspaceId, String actorType = 'user', String action = 'transfer.create', String status = 'success'}) → CoffrifyAuditEntry - Build a CoffrifyAuditEntry with overridable fields.
-
file(
{String? id, String? transferId, String? name, int size = 1024, String? mimeType}) → CoffrifyFile - Build a CoffrifyFile with overridable fields.
-
transfer(
{String? id, String? shortCode, String? workspaceId, String? userId, DateTime? createdAt, DateTime? expiresAt, String? status, bool? isPasswordProtected, int? maxDownloads, int? totalDownloads, bool? watermarkEnabled, bool burnAfterRead = false, String? transferTitle, String? notes, String? scanStatus, List< CoffrifyFile> ? files}) → CoffrifyTransfer - Build a CoffrifyTransfer with overridable fields.
-
webhook(
{String? id, String? name, String? url, List< String> ? events, bool isActive = true}) → CoffrifyWebhook - Build a CoffrifyWebhook with overridable fields.